<template>
    <view class="card">
        <view class="image-wrapper">
            <image class="image" src="https://ai-public.mastergo.com/ai/img_res/6a226f9e9652c51cd535c3490535dfeb.jpg"
                mode="aspectFill" />
            <view class="tag">{{ tag }}</view>
        </view>
        <view class="content">
            <view class="title">{{ title }}</view>
            <view class="subtitle">{{ subtitle }}</view>
            <view class="footer">
                <view class="rating">
                    <uni-icons class="star" type="star-filled" size="14" color="#FFD700" />
                    <text class="score">{{ score }}</text>
                </view>
                <view class="more" @click="goToDetail">
                    查看详情 ->
                </view>
            </view>
        </view>
    </view>
</template>
<script>
export default {
    name: 'TripCard',
    props: {
        tag: String,
        title: String,
        subtitle: String,
        score: {
            type: [String, Number],
            default: '5.0'
        },
        imageUrl: {
            type: String,
            required: true
        },
        detailUrl: {
            type: String,
            required: true
        }
    },
    methods: {
        goToDetail() {
            uni.navigateTo({
                url: this.detailUrl
            });
        },
        startExplore() {
            uni.showToast({ title: '开始探索', icon: 'none' })
        },
        hotRoute() {
            uni.showToast({ title: '热门路线', icon: 'none' })
        }
    }
}
</script>

<style scoped>
.card {
    /* margin: 30rpx; */
    margin-top: 30rpx;
    border-radius: 50rpx;
    overflow: hidden;
    background: #ffffff;
    box-shadow: 0 4rpx 12rpx rgba(0, 0, 0, 0.05);
}

.image-wrapper {
    position: relative;
    width: 100%;
    height: 260rpx;
}

.image {
    width: 100%;
    height: 100%;
}

.tag {
    position: absolute;
    bottom: 20rpx;
    left: 20rpx;
    padding: 6rpx 16rpx;
    background: rgba(0, 0, 0, 0.6);
    border-radius: 6rpx;
    color: #ffffff;
    font-size: 12px;
}

.content {
    padding: 24rpx;
    /* background: linear-gradient(180deg, rgba(0, 0, 0, 0.7) 0%, rgba(0, 0, 0, 0.9) 100%); */
    background-color: #121212;
}

.title {
    font-size: 16px;
    color: #ffffff;
    font-weight: 500;
    margin-bottom: 12rpx;
    line-height: 1.4;
}

.subtitle {
    font-size: 14px;
    color: rgba(255, 255, 255, 0.8);
    margin-bottom: 20rpx;
}

.footer {
    display: flex;
    justify-content: space-between;
    align-items: center;
}

.rating {
    display: flex;
    align-items: center;
}

.star {
    margin-right: 8rpx;
}

.score {
    color: #ffffff;
    font-size: 14px;
}

.more {
    color: #ffffff;
    font-size: 14px;
}
</style>